@@ -38,6 +38,7 @@ use crate::expression::compiler::builtin_functions::date_time::date_parts::{
     UTCYEAR_TRANSFORM, YEAR_TRANSFORM,
 };
 use crate::expression::compiler::builtin_functions::date_time::time::time_fn;
+use crate::expression::compiler::builtin_functions::format::format_transform;
 use crate::expression::compiler::builtin_functions::math::isfinite::is_finite_fn;
 use crate::expression::compiler::builtin_functions::type_checking::isdate::is_date_fn;
 use crate::expression::compiler::builtin_functions::type_coercion::to_boolean::to_boolean_transform;
@@ -387,6 +388,12 @@ pub fn default_callables() -> HashMap<String, VegaFusionCallable> {
         VegaFusionCallable::LocalTransform(Arc::new(utc_format_fn)),
     );
 
+    // format
+    callables.insert(
+        "format".to_string(),
+        VegaFusionCallable::Transform(Arc::new(format_transform)),
+    );
+
     // coercion
     callables.insert(
         "toBoolean".to_string(),
